/**
 * @copyright Cube Dev, Inc.
 * @license Apache-2.0
 * @fileoverview The `PrestoDriver` and related types declaration.
 */
/// <reference types="node" />
import { DownloadQueryResultsOptions, DownloadQueryResultsResult, DriverCapabilities, DriverInterface, StreamOptions, StreamTableData, TableStructure, BaseDriver, UnloadOptions } from '@cubejs-backend/base-driver';
import type { ConnectionOptions as TLSConnectionOptions } from 'tls';
export type PrestoDriverExportBucket = {
    exportBucket?: string;
    bucketType?: 'gcs' | 's3';
    credentials?: any;
    accessKeyId?: string;
    secretAccessKey?: string;
    exportBucketRegion?: string;
    exportBucketS3AdvancedFS?: boolean;
    exportBucketCsvEscapeSymbol?: string;
};
export type PrestoDriverConfiguration = PrestoDriverExportBucket & {
    host?: string;
    port?: string;
    catalog?: string;
    schema?: string;
    user?: string;
    custom_auth?: string;
    basic_auth?: {
        user: string;
        password: string;
    };
    ssl?: string | TLSConnectionOptions;
    dataSource?: string;
    queryTimeout?: number;
};
/**
 * Presto driver class.
 */
export declare class PrestoDriver extends BaseDriver implements DriverInterface {
    /**
     * Returns default concurrency value.
     */
    static getDefaultConcurrency(): number;
    protected readonly config: PrestoDriverConfiguration;
    protected readonly catalog: string | undefined;
    protected client: any;
    protected useSelectTestConnection: boolean;
    /**
     * Class constructor.
     */
    constructor(config?: PrestoDriverConfiguration);
    testConnection(): Promise<void>;
    protected testConnectionViaSelect(): Promise<void>;
    query(query: string, values: unknown[]): Promise<any[]>;
    prepareQueryWithParams(query: string, values: unknown[]): string;
    queryPromised(query: string, streaming: boolean): Promise<any[] | StreamTableData>;
    downloadQueryResults(query: string, values: unknown[], options: DownloadQueryResultsOptions): Promise<DownloadQueryResultsResult>;
    informationSchemaQuery(): string;
    normalizeResultOverColumns(data: any[], columns: TableStructure): {
        [x: string]: unknown;
    }[];
    stream(query: string, values: unknown[], _options: StreamOptions): Promise<StreamTableData>;
    capabilities(): DriverCapabilities;
    createSchemaIfNotExists(schemaName: string): Promise<void>;
    isUnloadSupported(): Promise<boolean>;
    unload(tableName: string, options: UnloadOptions): Promise<{
        exportBucketCsvEscapeSymbol: string | undefined;
        csvFile: string[];
        types: {
            name: string;
            type: string;
        }[];
        csvNoHeader: boolean;
    }>;
    private splitTableFullName;
    private generateTableColumnsForExport;
    private unloadWithSql;
    private unloadWithTable;
    private unloadGeneric;
    queryColumnTypes(sql: string, params: unknown[]): Promise<{
        name: string;
        type: string;
    }[]>;
    private getCsvFiles;
}
//# sourceMappingURL=PrestoDriver.d.ts.map